@@ -6,7 +6,7 @@ use vars qw[$VERSION %utilities];
 use Module::CoreList;
 use Module::CoreList::TieHashDelta;
 
-$VERSION = '5.20160507';
+$VERSION = '5.20160520';
 
 sub utilities {
     my $perl = shift;
@@ -1157,6 +1157,13 @@ my %delta = (
         removed => {
         }
     },
+    5.025001 => {
+        delta_from => 5.025000,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 for my $version (sort { $a <=> $b } keys %delta) {
